import * as React from "react";
import * as _ from "underscore";
import { Size, LayoutHelpers, Color, FgColorClass, BgColorClass, MarginClass, PaddingClass } from "./../../utilities/uiHelpers";
import { Icon } from "./../display/icon";
import { ClassHelpers } from "../../utilities/classNames";

export interface IButtonProps extends React.HTMLProps<HTMLButtonElement> {
  /** ((React.MouseEvent) => void) Event to fire when the button is clicked */
  onClick?: (e?: React.MouseEvent<{}>) => void;
  /** (string) An icon to show on the left of the buttons content */
  leftIcon?: string;
  /** (string) An icon to show on the right of the buttons content */
  rightIcon?: string;
  /** (boolean) Wether or not the button should have rounded edges */
  rounded?: boolean;
  /** (string) CSS classname property */
  className?: string | MarginClass | PaddingClass | BgColorClass | FgColorClass;
  /** (boolean) If true, disables actions and puts button into a 'pending' state */
  pending?: boolean;
}

export class Button extends React.Component<IButtonProps> {

  private handleClick = (e) => {
    const { onClick, pending } = this.props
    if (onClick && !pending) {
      onClick(e);
    }
  }
  
  render() {
    const { onClick, leftIcon, rightIcon, className, rounded, pending, disabled, type, children, ...attrs } = this.props
    //var attrs = _.omit(props, );
    const classes = ClassHelpers.classNames(
      "btn",
      className,
      {
        "rounded": rounded,
        "icon-button-left": leftIcon !== undefined,
        "icon-button-right": rightIcon !== undefined,
        "pending": pending
      }
    );
    return (
      <button disabled={pending || disabled} type={type || 'button'} onClick={this.handleClick} { ...attrs } className={classes}>
        {leftIcon && <Icon className="left-icon" icon={leftIcon} />}
        {children}
        {rightIcon && <Icon className="right-icon" icon={rightIcon} />}
      </button>
    );
  }
}
